package com.persagy.init;


import com.googlecode.aviator.AviatorEvaluator;
import com.persagy.cache.AlarmLastTimeCache;
import com.persagy.cache.CreatedAlarmIdsCache;
import com.persagy.client.GroupNettyClient;
import com.persagy.client.WebSocketClientFactory;
import com.persagy.service.AlarmQuartzService;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.CommandLineRunner;
import org.springframework.core.annotation.Order;
import org.springframework.stereotype.Service;


@Service
@Order(1)
@Slf4j
public class InitRunner implements CommandLineRunner {

	@Autowired
	private WebSocketClientFactory webSocketClientFactory;
	@Autowired
	private GroupNettyClient groupNettyClient;
	@Autowired
	AlarmQuartzService alarmQuartzService;
	@Autowired
	CreatedAlarmIdsCache createdAlarmIdsCache;
	@Autowired
	AlarmLastTimeCache alarmLastTimeCache;


	@Override
	public void run(String... args) throws Exception {
		// 已创建的报警id缓存初始化
		createdAlarmIdsCache.init();
		// 报警持续时间缓存初始化
		alarmLastTimeCache.init();
		//5.0 开始引入了 LRU 缓存，可指定缓存的表达式个数，比如设置为最大 1 万个缓存结果：
		AviatorEvaluator.getInstance().useLRUExpressionCache(10000);
		//启动netty客户端，接受云端数据
		groupNettyClient.start();
		//启动websocket,接受IOT采集数据
		webSocketClientFactory.retryOutCallWebSocketClient();
		alarmQuartzService.initAlarmMessagehandler();
	}
}
