package com.persagy.job;

import com.alibaba.fastjson.JSONObject;
import com.fasterxml.jackson.databind.node.ObjectNode;
import com.google.common.collect.Lists;
import com.persagy.cache.AlarmLastTimeCache;
import com.persagy.client.GroupNettyClient;
import com.persagy.entity.AlarmLastTime;
import com.persagy.entity.NettyMessage;
import com.persagy.enumeration.NettyMsgTypeEnum;
import com.persagy.enumeration.YesNoEnum;
import lombok.extern.slf4j.Slf4j;
import org.quartz.DisallowConcurrentExecution;
import org.quartz.JobExecutionContext;
import org.quartz.JobExecutionException;
import org.quartz.PersistJobDataAfterExecution;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.scheduling.quartz.QuartzJobBean;

import java.util.concurrent.ConcurrentHashMap;

/**
 * @description: 发送报警持续消息定时任务
 * @author: lixing
 * @company: Persagy Technology Co.,Ltd
 * @since: 2021/2/4 5:52 下午
 * @version: V1.0
 */
@DisallowConcurrentExecution
@PersistJobDataAfterExecution
@Slf4j
public class AlarmContinueJob extends QuartzJobBean {

    @Autowired
    private AlarmLastTimeCache alarmLastTimeCache;
    @Autowired
    GroupNettyClient groupNettyClient;

    @Override
    protected void executeInternal(JobExecutionContext context) throws JobExecutionException {
        ConcurrentHashMap<String, AlarmLastTime> alarmLastTimeMap = alarmLastTimeCache.getAll();
        if (alarmLastTimeMap.isEmpty()) {return;}
        for (String alarmId : alarmLastTimeMap.keySet()) {
            AlarmLastTime alarmLastTime = alarmLastTimeMap.get(alarmId);
            if (YesNoEnum.NO.equals(alarmLastTime.getHasSent()) &&
                    alarmLastTime.getAlarmLastMsg() != null &&
                    YesNoEnum.YES.equals(alarmLastTime.getAlarmHasCreated())) {
                // 发送报警持续时间
                NettyMessage<JSONObject> nettyMessage = new NettyMessage<>(
                        NettyMsgTypeEnum.ALARM_CONTINUE, alarmLastTime.getProjectId());
                ObjectNode alarmLastMsg = alarmLastTime.getAlarmLastMsg();
                JSONObject msg = (JSONObject)JSONObject.parse(alarmLastMsg.toString());
                nettyMessage.setContent(Lists.newArrayList(msg));
                try {
                    groupNettyClient.sendMessage(nettyMessage.toString());
                } catch (InterruptedException e) {
                    log.error("报警持续消息发送失败", e);
                }
                // 状态设置为已发送
                alarmLastTimeCache.updateHasSent(alarmId, YesNoEnum.YES);
            }
            if (YesNoEnum.YES.equals(alarmLastTime.getHasSent()) &&
                    YesNoEnum.YES.equals(alarmLastTime.getDeleteAvailable())) {
                alarmLastTimeCache.remove(alarmLastTime.getId());
            }
        }
    }
}
